clear
set more off
set matsize 2500
global path2b "D:\DAT\DPF\Analisis Financiero\Sector Hogares\EFH\Proyectos\2010_Household Risk\household_risk\empleo\bases"
global path4b "D:\DAT\DPF\Analisis Financiero\Sector Hogares\EFH\Proyectos\2010_Household Risk\simulation_time"
global path_g "D:\Docs2\EFH_CDI\Stress_test_probit\graphs"  //"D:\Docs2\EFH_CDI\Df_multiple_lenders\graphs\"  //"D:\Docs2\EFH_CDI\Default_Unem_NIE\graphs"

// Get Labor Force Data
use "$path4b\\unemployment_chile_q.dta", clear // Agg Un
use "$path2b\\emp_ene_x2.dta", clear
keep sexo year quarter zona2 tr_edad2 educ sector_ind population
save "$path2b\\pop_ene_x2.dta", replace  
use "$path2b\\emp_ing_x2.dta", clear
use "$path2b\\emp_ing_ocup_x2.dta", clear 
keep sexo zona2 tr_edad2 educ sector_ind quintile_renta population year unemployed
collapse (sum) population, by(sexo zona2 tr_edad2 educ sector_ind quintile_renta year)
rename quintile_renta quintile_h
save "$path2b\\pop_ing_ocup_x2.dta", replace  

// Group-specific Unemployment rates
use "$path2b\\emp_ene_x2.dta", clear
use "$path2b\\\emp_ene2_x2.dta", clear
sum year
joinby sexo zona2 tr_edad2 educ sector_ind quintile_h year using "$path2b\\pop_ing_ocup_x2.dta", unmatched(master) update
tab _merge
keep if _merge==3
drop _merge
joinby year quarter using "$path4b\\unemployment_chile_q.dta", unmatched(master) update
tab _merge
drop _merge
egen id = group(sexo zona2 tr_edad2 educ sector_ind quintile_h)
egen time = group(year quarter)
xtset id time
g unemployed_lag = L.unemployed
g unemp_rate_original=unemp_rate
save "$path2b\\\emp_data_temp.dta", replace

log using "$path_g\unemp_dynamics1.log", replace   //  Regs for NIE REC paper //
sum unemployed
local u1=r(max)
local u0=r(min)
reg unemployed i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)#c.(unemp_rate) i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)
reg unemployed i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)#c.(unemp_rate) i.(sexo zona2 tr_edad2 educ sector_ind quintile_h) [fw=population]
quietly {
forvalues i = 55(5)100 {
replace unemp_rate = `i'/1000
predict unemployed_`i'
replace unemployed_`i' = max(`u0', min(`u1', max(unemployed_`i', unemployed)) )
forvalues yi = 1990/2015 {
forvalues qi = 1/4 {
sum unemployed_`i' if year==`yi' & quarter==`qi' [fw=population]
local ra1=r(mean)
local ra0=(`i'/1000)/(`ra1')
replace unemployed_`i'=unemployed_`i'*`ra0' if year==`yi' & quarter==`qi' 
}
}
g d_unemployed_`i' = unemployed_`i'-unemployed
}
//  //   //
forvalues i = 60(5)100 { // This is to make increments of 0.5% each
g d2_unemployed_`i' = max(0, unemployed_`i'-unemployed_60) //max(0, d_unemployed_`i'-d_unemployed_60)
replace d_unemployed_`i' = min(d_unemployed_`i',d2_unemployed_`i')
}
replace d_unemployed_60=min(d_unemployed_60, d2_unemployed_60)
replace d_unemployed_65=min(d_unemployed_65, d2_unemployed_65)
drop unemployed_55 d_unemployed_55 d2_unemp*
//  //   //
}
replace unemp_rate=unemp_rate_original
sum unemp_rate_original unemployed unemployed_* d_unemployed_* if year==2014 & quarter==4 [fw=population]
reg unemployed i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)#c.(unemp_rate unemployed_lag) i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)
reg unemployed i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)#c.(unemp_rate unemployed_lag) i.(sexo zona2 tr_edad2 educ sector_ind quintile_h) [fw=population]
log close
log using "$path_g\unemp_dynamics2.log", replace   //  Regs for NIE REC paper //
reg unemployed i.(id)#c.(unemp_rate) i.(id)
reg unemployed i.(id)#c.(unemp_rate) i.(id) [fw=population]
log close
keep year quarter population sexo zona2 tr_edad2 educ sector_ind quintile_h unemployed* d_unemployed_*
save "$path_g\\stress_test_unemp_x2_allyears.dta", replace  
keep if year==2014 & quarter==4
collapse unemployed* d_unemployed_* population, by(sexo zona2 tr_edad2 educ sector_ind quintile_h)
save "$path_g\\stress_test_unemp_x2.dta", replace  

// Job-Find: pr_jobfind_inv pr_layoffs
use "$path2b\\\emp_data_temp.dta", clear
sum pr_jobfind_inv
local u1=r(max)
local u0=r(min)
reg pr_jobfind_inv i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)#c.(unemp_rate) i.(sexo zona2 tr_edad2 educ sector_ind quintile_h) [fw=population]
quietly {
forvalues i = 60(5)100 {
replace unemp_rate = `i'/1000
predict pr_jobfind_`i'
replace pr_jobfind_`i' = max(`u0', min(pr_jobfind_`i', pr_jobfind_inv))
g d_pr_jobfind_`i' = pr_jobfind_`i'-pr_jobfind_inv
}
}
keep year quarter sexo zona2 tr_edad2 educ sector_ind quintile_h pr_jobfind_* d_pr_jobfind_*
save "$path_g\\stress_test_jobfind_x2_allyears.dta", replace  
keep if year==2014 & quarter==4
collapse pr_jobfind_* d_pr_jobfind_*, by(sexo zona2 tr_edad2 educ sector_ind quintile_h)
save "$path_g\\stress_test_jobfind_x2.dta", replace 

// Layoffs
use "$path2b\\\emp_data_temp.dta", clear
sum pr_layoffs
local u1=r(max)
local u0=r(min)
reg pr_layoffs i.(sexo zona2 tr_edad2 educ sector_ind quintile_h)#c.(unemp_rate) i.(sexo zona2 tr_edad2 educ sector_ind quintile_h) [fw=population]
quietly {
forvalues i = 60(5)100 {
replace unemp_rate = `i'/1000
predict pr_layoffs_`i'
replace pr_layoffs_`i' = min(`u1', max(pr_layoffs_`i', pr_layoffs))
g d_pr_layoffs_`i' = pr_layoffs_`i'-pr_layoffs
}
}
keep year quarter sexo zona2 tr_edad2 educ sector_ind quintile_h pr_layoffs_* d_pr_layoffs*
save "$path_g\\stress_test_layoffs_x2_allyears.dta", replace  
keep if year==2014 & quarter==4
collapse pr_layoffs_* d_pr_layoffs*, by(sexo zona2 tr_edad2 educ sector_ind quintile_h)
save "$path_g\\stress_test_layoffs_x2.dta", replace 
