// Estimates equivalence measures for each type of household from the EPF family's income and consumption data

noisily {
if ${print_regs}==1 {  // Print regressions
capture log close
log using "$path4b\epf_equivalence_c.log", replace 
}
local option_constant = 1 // 1 - Includes constant in consumption log-regs (implies consumption is positive with 0 income)
// 0 - Excludes constant  // Both options give similar results, but I opt for option 1

use "$path4b\expenditures_${data_save_emp}.dta", clear
drop if pco1!=1
capture drop exp_p25 arriendo_p50
local cond_vars "zona2 vivprop num_adul num_men num_sen tedu tr_edad2 quintile_h"
pctile_wgts exp_p25 gasto_tot "`cond_vars'" factor 20
pctile_wgts exp_p75 gasto_tot "`cond_vars'" factor 80
pctile_wgts arriendo_p50 arriendo_imputado "`cond_vars'" factor 50
pctile_wgts exp_ndur_p25 gasto_no_durable "`cond_vars'" factor 20
pctile_wgts exp_ndur_p75 gasto_no_durable "`cond_vars'" factor 80
collapse arriendo_p50 exp_p25 exp_p75 exp_ndur_p25 exp_ndur_p75 [fw=factor], by(`cond_vars')
save "$path4b\exp_p25_${data_save_emp}.dta", replace

use "$path4b\expenditures_${data_save_emp}.dta", clear
drop if pco1!=1
// unemp_rr_sect unemp_sect rr_inc_sect sd_ln_inc_sect
g desem2 = desem
g unemp_rr_sect = unemp_sect*(1-rr_inc_sect)
/*
quietly {
foreach x in unemp_rr_sect rr_inc_sect {
bysort tr_edad2 tedu zona2 quintile_h: egen `x'0 = median(`x')
replace `x' =  `x'0 if  `x'==.
replace `x' =  `x'0 if  `x'==0
drop `x'0
sum `x' if  `x'>0
replace `x' = max( r(min),  `x' )
}
}
*/
local cond_vars "zona2 vivprop num_adul num_men num_sen tr_edad2 desem2" //    tedu quintile_h 
local cond_vars2 "zona2##num_adul##num_men##num_sen" // tedu quintile_h 
local cond_vars3 "zona2 vivprop num_adul num_men num_sen tr_edad2 desem2" //   desem tedu quintile_h 
sum tr_edad2
local min_age = r(min)
local max_age = r(max)

sum ytoth ytoth_cons ytot_p_h ytoth_pi_exp ytoth_pi [fw=factor]
pwcorr ytoth ytoth_cons ytot_p_h ytoth_pi_exp ytoth_pi [fw=factor]
pwcorr ytoth ytoth_cons ytot_p_h ytoth_pi_exp ytoth_pi if ytot_p_h<ytoth & ytoth<. [fw=factor]
pwcorr ytoth ytoth_cons ytot_p_h ytoth_pi_exp ytoth_pi if ytot_p_h>ytoth & ytot_p_h<. [fw=factor]
drop ytoth 
sum ytoth_cons if ytoth_cons>0
replace ytoth_cons = log( ytoth_cons + abs(r(min)) + 1000 )
g ytoth = ytoth_cons
quietly {
foreach x in unemp_rr_sect unemp_sect sd_ln_inc_sect {
sum `x' if  `x'>0
replace `x' = max( r(min),  `x' )
replace `x' = 0 if desem2==1
}
}
*replace unemp_rr_sect = rr_inc_sect if desem2==1
*replace unemp_rr_sect = ln( unemp_rr_sect + abs(r(min)) + 1 ) if desem2==0
sum unemp_rr_sect if unemp_rr_sect>0

sum gasto* *sect
pwcorr gasto* *sect
pwcorr gasto* *sect [fw=factor]

foreach var_c in tot durable no_durable {
g pir_`var_c' = gasto_`var_c'/exp(ytoth_cons)
sum pir_`var_c', d
g pir2_`var_c' = pir_`var_c'
sum gasto_`var_c'
replace gasto_`var_c' = log( gasto_`var_c' + abs(r(min)) + 1000 )

foreach per_c in 25 50 75 {  // 25 50 75
pctile_wgts equi_c_`var_c'_p`per_c' gasto_`var_c' "`cond_vars'" factor `per_c'
sum equi_c_`var_c'_p`per_c' [fw=factor], d
replace equi_c_`var_c'_p`per_c' = max(r(p5), equi_c_`var_c'_p`per_c')
replace equi_c_`var_c'_p`per_c' = min(r(p95), equi_c_`var_c'_p`per_c')
}
replace gasto_`var_c' = gasto_`var_c' - equi_c_`var_c'_p50
//

sum gasto_`var_c' [fw=factor], d
local min_obs = r(p1)
local max_obs = r(p99)
bysort `cond_vars3': egen max_obs = pctile(gasto_`var_c'), p(95)
bysort `cond_vars3': egen min_obs = pctile(gasto_`var_c'), p(5)
g sd_equi_c_`var_c' = .
g mpc_inc_`var_c' = .
g mpc_sdi_`var_c' = .
g mpc_urr_`var_c' = .

// I shut down this loop for age coefficients
local vars_reg "ytoth sd_ln_inc_sect" // other vars: unemp_rr_sect 
*forv age_k= `min_age'/`max_age' {
if `option_constant'==1 {
*reg gasto_`var_c' ytoth sd_ln_inc_sect if tr_edad2==`age_k' & gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs [fw=factor]
if ${print_regs}==1 { 
reg gasto_`var_c' `vars_reg' if gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs, vce(robust)
reg gasto_`var_c' `vars_reg' if gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs [fw=factor], vce(jackknife, nodots)
}
reg gasto_`var_c' `vars_reg' if gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs [fw=factor] 
}
if `option_constant'==0 {
*reg gasto_`var_c' ytoth sd_ln_inc_sect if tr_edad2==`age_k' & gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs [fw=factor], noconstant 
if ${print_regs}==1 { 
reg gasto_`var_c' `vars_reg' if gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs, noconstant vce(robust)
reg gasto_`var_c' `vars_reg' if gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs [fw=factor], noconstant vce(jackknife, nodots)
}
reg gasto_`var_c' `vars_reg' if gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs [fw=factor], noconstant 
}
predict sd_equi_c0, residuals
*replace sd_equi_c_`var_c' = abs(sd_equi_c0) if tr_edad2==`age_k' &  gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs
replace sd_equi_c_`var_c' = abs(sd_equi_c0) if gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs
drop sd_equi_c0
//
local b_coef = _b[ytoth]
local b_coef = min(0.99, max( 0.25, `b_coef'))  //0.20 0.25 0.40 0r 0.50
*replace mpc_inc_`var_c' = `b_coef' if tr_edad2==`age_k'
replace mpc_inc_`var_c' = `b_coef' 
local b_coef = _b[sd_ln_inc_sect]
local b_coef = min(0, `b_coef')  // coefficient is non-positive
replace mpc_sdi_`var_c' = `b_coef' 
*local b_coef = _b[unemp_rr_sect]
*local b_coef = min(0, `b_coef')  // coefficient is non-positive
*replace mpc_urr_`var_c' = `b_coef' 
//

if `option_constant'==1 {
local b_coef = _b[_cons]
foreach per_c in 25 50 75 {  // 25 50 75
*replace equi_c_`var_c'_p`per_c' = equi_c_`var_c'_p`per_c' + `b_coef' if tr_edad2==`age_k'
replace equi_c_`var_c'_p`per_c' = equi_c_`var_c'_p`per_c' + `b_coef' 
}
}
*}
//
sum mpc_inc_`var_c' sd_equi_c_`var_c' [fw=factor], d
g equi_c_`var_c' = equi_c_`var_c'_p50
*replace equi_c_`var_c' = exp( equi_c_`var_c' )

drop equi_c_`var_c'_p75 equi_c_`var_c'_p25 min_obs max_obs

bysort `cond_vars3': egen max_obs = pctile(sd_equi_c_`var_c'), p(90)
bysort `cond_vars3': egen min_obs = pctile(sd_equi_c_`var_c'), p(10)
replace sd_equi_c_`var_c' = min(sd_equi_c_`var_c', max_obs)
replace sd_equi_c_`var_c' = max(sd_equi_c_`var_c', min_obs)
drop min_obs max_obs
}
//
keep factor mpc_inc* mpc_sdi* mpc_urr* gasto_* equi_c_* sd_equi_c_* `cond_vars' pir_* pir2_*
collapse (mean) mpc_inc* mpc_sdi* mpc_urr* equi_c_*_p50 (mean) sd_equi_c_* (p75) pir_* (p90) pir2_* [fw=factor], by(`cond_vars')
// 
drop if tr_edad2==.
save "$path4b\equi_c_${data_save_emp}.dta", replace
//
if ${print_regs}==1 {  // Print regressions
capture log close
}
}
//
